@@ -3,10 +3,10 @@ package RFID::Libnfc::Tag::ISO14443A_106::4K;
 use strict;
 
 use base qw(RFID::Libnfc::Tag::ISO14443A_106);
-use RFID::Libnfc qw(nfc_initiator_select_tag nfc_initiator_transceive_dep_bytes print_hex);
+use RFID::Libnfc qw(nfc_initiator_select_tag nfc_initiator_transceive_bytes print_hex);
 use RFID::Libnfc::Constants;
 
-our $VERSION = '0.10';
+our $VERSION = '0.11';
 
 # Internal representation of TABLE 3 (M001053_MF1ICS50_rev5_3.pdf)
 # the key are the actual ACL bits (C1 C2 C3) ,
@@ -92,7 +92,7 @@ sub read_block {
             $self->unlock($sector, (@{$acl->{parsed}->{$datanum}}[0] == 2) ? MC_AUTH_B : MC_AUTH_A);
     }
     my $initiator_exchange_data = pack("C5", 0xD4, 0x40, 0x01, MC_READ, $block);
-    if (my $resp = nfc_initiator_transceive_dep_bytes($self->reader->pdi, $initiatior_exchange_data, 5)) {
+    if (my $resp = nfc_initiator_transceive_bytes($self->reader->pdi, $initiatior_exchange_data, 5)) {
         return unpack("a16", $resp); 
     } else {
         $self->{_last_error} = "Error reading $sector, block $block"; # XXX - does libnfc provide any clue on the ongoing error?
@@ -130,7 +130,7 @@ sub write_block {
     }
 
     my $initiator_exchange_data = pack("C5a16", 0xD4, 0x40, 0x01, MC_WRITE, $block, $data);
-    if (nfc_initiator_transceive_dep_bytes($self->reader->pdi, $initiatior_exchange_data, 5+16)) {
+    if (nfc_initiator_transceive_bytes($self->reader->pdi, $initiatior_exchange_data, 5+16)) {
         return 1;
     } else {
         # XXX can libnfc provide more info about the failure?
@@ -191,7 +191,7 @@ sub unlock {
         "%x " x 6 . " ---- " . "%x " x 4 . "\n", unpack("C10", $mpt->mpa)) if $self->{debug};
 
     my $initiator_exchange_data = pack("C5a6C4", 0xD4, 0x40, 0x01, $keytype, $tblock, $self->{_keys}->[$sector][$keyidx], @{$self->uid});
-    return 1 if (nfc_initiator_transceive_dep_bytes($self->reader->pdi, $initiatior_exchange_data, 5+6+4));
+    return 1 if (nfc_initiator_transceive_bytes($self->reader->pdi, $initiatior_exchange_data, 5+6+4));
 
     $self->{_last_error} = "Failed to authenticate on sector $sector (tblock:$tblock) with key " .
         sprintf("%x " x 6 . "\n", unpack("C6", $mpt->mpa));
@@ -205,7 +205,7 @@ sub acl {
 
     if ($self->unlock($sector)) {
         my $initiator_exchange_data = pack("C5", 0xD4, 0x40, 0x01, MC_READ, $tblock);
-        if (nfc_initiator_transceive_dep_bytes($self->reader->pdi, $initiator_exchange_data, 5)) {
+        if (nfc_initiator_transceive_bytes($self->reader->pdi, $initiator_exchange_data, 5)) {
             my $j = $mpt->mpd;
             return $self->_parse_acl(unpack("x6a4x6", $mpt->mpd));
         }
